@@ -17,7 +17,7 @@
     02110-1301, USA.
 */
 
-#include <qtest.h>
+#include <QTest>
 
 #include "kimaptest/fakeserver.h"
 #include "kimap/loginjob.h"
